@@ -1,7 +1,5 @@
 package Dist::Zilla::PluginBundle::FAYLAND;
-{
-    $Dist::Zilla::PluginBundle::FAYLAND::VERSION = '0.12';
-}
+$Dist::Zilla::PluginBundle::FAYLAND::VERSION = '0.13';
 
 # ABSTRACT: Dist::Zilla like FAYLAND when you build your dists
 
@@ -37,7 +35,7 @@ sub bundle_config {
         [ ReadmeFromPod       => {} ],
         [ CheckChangeLog      => {} ],
         [ MetaJSON            => {} ],
-        [ ContributorsFromGit => {} ]
+        [ 'Git::Contributors' => {} ]
       );
 
     push @plugins, @extra;
@@ -56,13 +54,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::PluginBundle::FAYLAND - Dist::Zilla like FAYLAND when you build your dists
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -84,6 +84,7 @@ It is equivalent to:
     [ReadmeFromPod]
     [CheckChangeLog]
     [MetaJSON]
+    [Git::Contributors]
 
 =head1 AUTHOR
 
@@ -91,7 +92,7 @@ Fayland Lam <fayland@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Fayland Lam.
+This software is copyright (c) 2015 by Fayland Lam.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
